@@ -33,9 +33,10 @@
 #include "camel-kolab-imapx-metadata.h"
 
 /*----------------------------------------------------------------------------*/
-/* local helpers */
+/* local statics */
+
 static void
-kolab_mail_summary_util_e_cal_component_free_text (ECalComponentText *ect)
+mail_summary_util_e_cal_component_free_text (ECalComponentText *ect)
 {
 	if (ect == NULL)
 		return;
@@ -43,7 +44,7 @@ kolab_mail_summary_util_e_cal_component_free_text (ECalComponentText *ect)
 }
 
 static void
-kolab_mail_summary_util_e_cal_component_free_organizer (ECalComponentOrganizer *eco)
+mail_summary_util_e_cal_component_free_organizer (ECalComponentOrganizer *eco)
 {
 	if (eco == NULL)
 		return;
@@ -100,7 +101,7 @@ kolab_mail_summary_new_from_ecalcomponent (ECalComponent *ecalcomp)
 		kolab_mail_summary_set_char_field (summary,
 		                                   KOLAB_MAIL_SUMMARY_CHAR_FIELD_E_SUMMARY,
 		                                   g_strdup (ect->value));
-		kolab_mail_summary_util_e_cal_component_free_text (ect);
+		mail_summary_util_e_cal_component_free_text (ect);
 	}
 
 	{ /* ORGANIZER */
@@ -109,7 +110,7 @@ kolab_mail_summary_new_from_ecalcomponent (ECalComponent *ecalcomp)
 		kolab_mail_summary_set_char_field (summary,
 		                                   KOLAB_MAIL_SUMMARY_CHAR_FIELD_E_ORGANIZER,
 		                                   g_strdup (eco->value));
-		kolab_mail_summary_util_e_cal_component_free_organizer (eco);
+		mail_summary_util_e_cal_component_free_organizer (eco);
 	}
 
 	{ /* LOCATION */
