@@ -28,6 +28,8 @@
 #define _XOPEN_SOURCE
 #define _POSIX_SOURCE
 
+#include <libekolabutil/kolab-util.h>
+
 #include <stdio.h>
 #include <unistd.h>
 #include <logging.h>
@@ -194,7 +196,7 @@ add_klb_mail_list_to_g_mime_message (GMimeMessage *message, const GList* klb_mai
 
 			Kolab_conv_mail_part *klb_mail_part = ((Kolab_conv_mail_part*) iterator->data);
 
-			gchar **tokens = g_strsplit (klb_mail_part->mime_type, "/", -1);
+			gchar **tokens = g_strsplit (klb_mail_part->mime_type, KOLAB_PATH_SEPARATOR_S, -1);
 
 			mime_part = g_mime_part_new_with_type (tokens[0], tokens[1]);
 
@@ -386,7 +388,7 @@ read_kolab_email_file(const gchar *filename, GError** error) {
 			if( file_buf ){
 				klb_mail_part = g_new0(Kolab_conv_mail_part , 1);
 				strcpy (contentType, g_mime_obj->content_type->type);
-				strcat (contentType, "/");
+				strcat (contentType, KOLAB_PATH_SEPARATOR_S);
 				strcat (contentType, g_mime_obj->content_type->subtype);
 
 				if(fileName)
